pub struct DeltaBuffers<'a, D: PointCoord> {
pub deltas: &'a mut [Point<D>],
pub iup: &'a mut [Point<D>],
}Expand description
Caller-provided storage for Gvar::simple_deltas and
GlyphVariationData::simple_deltas.
Both slices must be at least as long as the glyph’s point count, including the phantom points.
Fields
deltas: &'a mut [Point<D>]Receives the computed deltas.
iup: &'a mut [Point<D>]Working space used to interpolate the deltas of points that a sparse tuple does not reference.