pub struct GlyphVariationDataHeader<'a> {
data: FontData<'a>,
}Expand description
The GlyphVariationData table
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> GlyphVariationDataHeader<'a>
impl<'a> GlyphVariationDataHeader<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn tuple_variation_count(&self) -> TupleVariationCount
pub fn tuple_variation_count(&self) -> TupleVariationCount
A packed field. The high 4 bits are flags, and the low 12 bits are the number of tuple variation tables for this glyph. The number of tuple variation tables can be any number between 1 and 4095.
Sourcepub fn serialized_data_offset(&self) -> Offset16
pub fn serialized_data_offset(&self) -> Offset16
Offset from the start of the GlyphVariationData table to the serialized data
Sourcepub fn serialized_data(&self) -> Result<FontData<'a>, ReadError>
pub fn serialized_data(&self) -> Result<FontData<'a>, ReadError>
Attempt to resolve serialized_data_offset.
Sourcepub fn tuple_variation_headers(
&self,
) -> VarLenArray<'a, TupleVariationHeader<'a>>
pub fn tuple_variation_headers( &self, ) -> VarLenArray<'a, TupleVariationHeader<'a>>
Array of tuple variation headers.
pub fn tuple_variation_count_byte_range(&self) -> Range<usize> ⓘ
pub fn serialized_data_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn tuple_variation_headers_byte_range(&self) -> Range<usize> ⓘ
Sourceimpl<'a> GlyphVariationDataHeader<'a>
impl<'a> GlyphVariationDataHeader<'a>
fn raw_tuple_header_data(&self) -> FontData<'a>