Gvar

Struct Gvar 

pub struct Gvar<'a> {
    data: FontData<'a>,
}
Fields

data: FontData<'a>

Implementations

Source

impl<'a> Gvar<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn version(&self) -> MajorMinor

Major/minor version number of the glyph variations table — set to (1,0).

pub fn axis_count(&self) -> u16

The number of variation axes for this font. This must be the same number as axisCount in the ‘fvar’ table.

pub fn shared_tuple_count(&self) -> u16

The number of shared tuple records. Shared tuple records can be referenced within glyph variation data tables for multiple glyphs, as opposed to other tuple records stored directly within a glyph variation data table.

pub fn shared_tuples_offset(&self) -> Offset32

Offset from the start of this table to the shared tuple records.

pub fn shared_tuples(&self) -> Result<SharedTuples<'a>, ReadError>

Attempt to resolve shared_tuples_offset.

pub fn glyph_count(&self) -> u16

The number of glyphs in this font. This must match the number of glyphs stored elsewhere in the font.

pub fn flags(&self) -> GvarFlags

Bit-field that gives the format of the offset array that follows. If bit 0 is clear, the offsets are uint16; if bit 0 is set, the offsets are uint32.

pub fn glyph_variation_data_array_offset(&self) -> u32

Offset from the start of this table to the array of GlyphVariationData tables.

pub fn glyph_variation_data_offsets(&self) -> ComputedArray<'a, U16Or32>

Offsets from the start of the GlyphVariationData array to each GlyphVariationData table.

pub fn version_byte_range(&self) -> Range<usize>

pub fn axis_count_byte_range(&self) -> Range<usize>

pub fn shared_tuple_count_byte_range(&self) -> Range<usize>

pub fn shared_tuples_offset_byte_range(&self) -> Range<usize>

pub fn glyph_count_byte_range(&self) -> Range<usize>

pub fn flags_byte_range(&self) -> Range<usize>

pub fn glyph_variation_data_array_offset_byte_range(&self) -> Range<usize>

pub fn glyph_variation_data_offsets_byte_range(&self) -> Range<usize>

Source

impl<'a> Gvar<'a>

pub fn data_for_gid( &self, gid: GlyphId, ) -> Result<Option<FontData<'a>>, ReadError>

Return the raw data for this gid.

If there is no variation data for the glyph, returns Ok(None).

pub fn glyph_variation_data_for_range( &self, offset_range: Range<usize>, ) -> Result<FontData<'a>, ReadError>

pub fn as_bytes(&self) -> &[u8]

fn data_range_for_gid(&self, gid: GlyphId) -> Result<Range<usize>, ReadError>

pub fn glyph_variation_data( &self, gid: GlyphId, ) -> Result<Option<GlyphVariationData<'a>>, ReadError>

Get the variation data for a specific glyph.

Returns Ok(None) if there is no variation data for this glyph, and returns an error if there is data but it is malformed.

pub fn phantom_point_deltas( &self, glyf: &Glyf<'_>, loca: &Loca<'_>, coords: &[F2Dot14], glyph_id: GlyphId, ) -> Result<Option<[Point<Fixed>; 4]>, ReadError>

Returns the phantom point deltas for the given variation coordinates and glyph identifier, if variation data exists for the glyph.

The resulting array will contain four deltas: [left, right, top, bottom].