pub struct SharedTuples<'a> {
data: FontData<'a>,
shared_tuple_count: u16,
axis_count: u16,
}Expand description
Array of tuple records shared across all glyph variation data tables.
Fields
data: FontData<'a>axis_count: u16Implementations
pub const MIN_SIZE: usize = 0
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
pub fn tuples(&self) -> ComputedArray<'a, Tuple<'a>>
pub(crate) fn axis_count(&self) -> u16
pub fn tuples_byte_range(&self) -> Range<usize> ⓘ